"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NftClient = void 0;
const shared_1 = require("../../shared");
const operations_1 = require("./operations");
class NftClient extends shared_1.ModuleClient {
    findNftByMint(mint) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.metaplex.execute(new operations_1.FindNftByMintOperation(mint));
        });
    }
    findNftsByMintList(mints) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.metaplex.execute(new operations_1.FindNftsByMintListOperation(mints));
        });
    }
    findNftsByOwner(owner) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.metaplex.execute(new operations_1.FindNftsByOwnerOperation(owner));
        });
    }
    findNftsByCreator(creator, position = 1) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.metaplex.execute(new operations_1.FindNftsByCreatorOperation({ creator, position }));
        });
    }
    findNftsByCandyMachine(candyMachine, version) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.metaplex.execute(new operations_1.FindNftsByCandyMachineOperation({ candyMachine, version }));
        });
    }
    uploadMetadata(input, confirmOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.metaplex.execute(new operations_1.UploadMetadataOperation(input), confirmOptions);
        });
    }
    planUploadMetadata(input, confirmOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.metaplex.execute(new operations_1.PlanUploadMetadataOperation(input), confirmOptions);
        });
    }
    createNft(input, confirmOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            const operation = new operations_1.CreateNftOperation(input);
            const createNftOutput = yield this.metaplex.execute(operation, confirmOptions);
            const nft = yield this.findNftByMint(createNftOutput.mint.publicKey);
            return Object.assign(Object.assign({}, createNftOutput), { nft });
        });
    }
    updateNft(nft, input, confirmOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            const operation = new operations_1.UpdateNftOperation(Object.assign(Object.assign({}, input), { nft }));
            const updateNftOutput = yield this.metaplex.execute(operation, confirmOptions);
            const updatedNft = yield this.findNftByMint(nft.mint);
            return Object.assign(Object.assign({}, updateNftOutput), { nft: updatedNft });
        });
    }
}
exports.NftClient = NftClient;
//# sourceMappingURL=NftClient.js.map