"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlanUploadMetadataOperationHandler = void 0;
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const drivers_1 = require("../../../drivers");
const shared_1 = require("../../../shared");
const utils_1 = require("../../../utils");
class PlanUploadMetadataOperationHandler extends shared_1.OperationHandler {
    handle(operation) {
        return __awaiter(this, void 0, void 0, function* () {
            const metadata = operation.input;
            const files = this.getAssetsFromJsonMetadata(metadata);
            if (files.length <= 0) {
                return shared_1.Plan.make().addStep({
                    name: 'Upload the metadata',
                    handler: () => this.uploadMetadata(metadata),
                });
            }
            return shared_1.Plan.make()
                .addStep({
                name: 'Upload assets',
                handler: () => this.uploadAssets(metadata),
            })
                .addStep({
                name: 'Upload the metadata',
                handler: (input) => this.uploadMetadata(input),
            });
        });
    }
    uploadAssets(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const files = this.getAssetsFromJsonMetadata(input);
            const uris = yield this.metaplex.storage().uploadAll(files);
            return this.replaceAssetsWithUris(input, uris);
        });
    }
    uploadMetadata(metadata) {
        return __awaiter(this, void 0, void 0, function* () {
            const uri = yield this.metaplex.storage().uploadJson(metadata);
            return { metadata, uri };
        });
    }
    getAssetsFromJsonMetadata(input) {
        const files = [];
        (0, utils_1.walk)(input, (walk, value) => {
            if (value instanceof drivers_1.MetaplexFile) {
                files.push(value);
            }
            else {
                walk(value);
            }
        });
        return files;
    }
    replaceAssetsWithUris(input, replacements) {
        const clone = (0, lodash_clonedeep_1.default)(input);
        let index = 0;
        (0, utils_1.walk)(clone, (walk, value, key, parent) => {
            if (value instanceof drivers_1.MetaplexFile && index < replacements.length) {
                parent[key] = replacements[index++];
            }
            walk(value);
        });
        return clone;
    }
}
exports.PlanUploadMetadataOperationHandler = PlanUploadMetadataOperationHandler;
//# sourceMappingURL=PlanUploadMetadataOperationHandler.js.map