"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Loader = void 0;
class Loader {
    constructor() {
        this.status = 'pending';
    }
    setAbortSignal(abortSignal) {
        this.abortSignal = abortSignal;
        return this;
    }
    reload(metaplex, options = {}) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function* () {
            if (this.isLoading()) {
                // TODO: Custom errors.
                throw new Error('Loader is already running.');
            }
            // Prepare abort listener.
            const abortListener = (reason) => {
                this.status = 'canceled';
                this.error = reason;
            };
            (_a = this.abortSignal) === null || _a === void 0 ? void 0 : _a.addEventListener('abort', abortListener, { once: true });
            try {
                // Start loading.
                this.status = 'running';
                this.error = undefined;
                this.result = yield this.handle(metaplex);
                // Mark as successful if the loader wasn't aborted.
                if (!this.wasCanceled()) {
                    this.status = 'successful';
                }
                // Return the loaded result.
                return this.result;
            }
            catch (error) {
                // Capture the error and reset the result.
                this.error = error;
                this.result = undefined;
                // Mark as failed if the loader wasn't aborted.
                if (!this.wasCanceled()) {
                    this.status = 'failed';
                }
                // Return undefined result if loaded aborted or if we want to fail silently.
                if (this.wasCanceled() || ((_b = options.failSilently) !== null && _b !== void 0 ? _b : false)) {
                    return this.result;
                }
                // Otherwise, re-throw the error.
                throw error;
            }
            finally {
                // Clean up the abort listener.
                (_c = this.abortSignal) === null || _c === void 0 ? void 0 : _c.removeEventListener('abort', abortListener);
            }
        });
    }
    load(metaplex, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.isPending()) {
                return this.result;
            }
            return this.reload(metaplex, options);
        });
    }
    reset() {
        this.status = 'pending';
        this.result = undefined;
        this.error = undefined;
        return this;
    }
    loadWith(preloadedResult) {
        this.status = 'successful';
        this.result = preloadedResult;
        this.error = undefined;
        return this;
    }
    getStatus() {
        return this.status;
    }
    getResult() {
        return this.result;
    }
    getError() {
        return this.error;
    }
    isPending() {
        return this.status === 'pending';
    }
    isLoading() {
        return this.status === 'running';
    }
    isLoaded() {
        return this.status !== 'pending' && this.status !== 'running';
    }
    wasSuccessful() {
        return this.status === 'successful';
    }
    wasFailed() {
        return this.status === 'failed';
    }
    wasCanceled() {
        return this.status === 'canceled';
    }
}
exports.Loader = Loader;
//# sourceMappingURL=Loader.js.map