import { Model } from "../../../shared";
import { JsonMetadataLoader } from './JsonMetadataLoader';
import { removeEmptyChars } from "../../../utils";
import { MasterEditionLoader } from './MasterEditionLoader';
export class Nft extends Model {
    /** The Metadata PDA account defining the NFT. */
    metadataAccount;
    /** Loaders. */
    metadataLoader;
    masterEditionLoader;
    /** Data from the Metadata account. */
    updateAuthority;
    mint;
    name;
    symbol;
    uri;
    sellerFeeBasisPoints;
    creators;
    primarySaleHappened;
    isMutable;
    editionNonce;
    tokenStandard;
    collection;
    uses;
    constructor(metadataAccount) {
        super();
        this.metadataAccount = metadataAccount;
        this.metadataLoader = new JsonMetadataLoader(this);
        this.masterEditionLoader = new MasterEditionLoader(this);
        this.updateAuthority = metadataAccount.data.updateAuthority;
        this.mint = metadataAccount.data.mint;
        this.name = removeEmptyChars(metadataAccount.data.data.name);
        this.symbol = removeEmptyChars(metadataAccount.data.data.symbol);
        this.uri = removeEmptyChars(metadataAccount.data.data.uri);
        this.sellerFeeBasisPoints = metadataAccount.data.data.sellerFeeBasisPoints;
        this.creators = metadataAccount.data.data.creators;
        this.primarySaleHappened = metadataAccount.data.primarySaleHappened;
        this.isMutable = metadataAccount.data.isMutable;
        this.editionNonce = metadataAccount.data.editionNonce;
        this.tokenStandard = metadataAccount.data.tokenStandard;
        this.collection = metadataAccount.data.collection;
        this.uses = metadataAccount.data.uses;
    }
    get metadata() {
        return this.metadataLoader.getResult() ?? {};
    }
    get masterEditionAccount() {
        return this.masterEditionLoader.getResult() ?? null;
    }
    get masterEdition() {
        return this.masterEditionAccount?.data ?? {};
    }
    is(other) {
        const mint = other instanceof Nft ? other.mint : other;
        return this.mint.equals(mint);
    }
}
//# sourceMappingURL=Nft.js.map