/// <reference types="node" />
import { Buffer } from 'buffer';
import { AccountInfo, Commitment, ConfirmOptions, Connection, PublicKey, RpcResponseAndContext, SendOptions, SignatureResult, Transaction, TransactionSignature } from '@solana/web3.js';
import { IdentityDriver, StorageDriver } from "./drivers";
import { InputOfOperation, Operation, OperationConstructor, OperationHandlerConstructor, OutputOfOperation, TransactionBuilder, Signer } from "./shared";
import { MetaplexPlugin } from "./MetaplexPlugin";
export declare type MetaplexOptions = {};
export declare class Metaplex {
    /** The connection object from Solana's SDK. */
    readonly connection: Connection;
    /** Options that dictate how to interact with the Metaplex SDK. */
    readonly options: MetaplexOptions;
    /** Encapsulates the identity of the users interacting with the SDK. */
    protected identityDriver: IdentityDriver;
    /** Encapsulates where assets should be uploaded. */
    protected storageDriver: StorageDriver;
    /** The registered handlers for read/write operations. */
    protected operationHandlers: Map<any, any>;
    constructor(connection: Connection, options?: MetaplexOptions);
    static make(connection: Connection, options?: MetaplexOptions): Metaplex;
    registerDefaultPlugins(): void;
    use(plugin: MetaplexPlugin): this;
    identity(): IdentityDriver;
    setIdentity(identity: IdentityDriver): this;
    storage(): StorageDriver;
    setStorage(storage: StorageDriver): this;
    sendTransaction(transaction: Transaction | TransactionBuilder, signers?: Signer[], sendOptions?: SendOptions): Promise<TransactionSignature>;
    confirmTransaction(signature: TransactionSignature, commitment?: Commitment): Promise<RpcResponseAndContext<SignatureResult>>;
    sendAndConfirmTransaction(transaction: Transaction | TransactionBuilder, signers?: Signer[], confirmOptions?: ConfirmOptions): Promise<TransactionSignature>;
    getAccountInfo(publicKey: PublicKey, commitment?: Commitment): Promise<AccountInfo<Buffer> | null>;
    getMultipleAccountsInfo(publicKeys: PublicKey[], commitment?: Commitment): Promise<(AccountInfo<Buffer> | null)[]>;
    register<T extends Operation<I, O>, I = InputOfOperation<T>, O = OutputOfOperation<T>>(operation: OperationConstructor<I, O>, operationHandler: OperationHandlerConstructor<T, I, O>): this;
    execute<T extends Operation<I, O>, I = InputOfOperation<T>, O = OutputOfOperation<T>>(operation: T, confirmOptions?: ConfirmOptions): Promise<O>;
}
